@@ -65,8 +65,9 @@ class ClearCalendarScreenlet(screenlets.Screenlet):
 	
 	# default meta-info for Screenlets
 	__name__ = 'ClearCalendarScreenlet'
-	__version__ = '0.4.4+++'
+	__version__ = '0.4.4++++'
 	__author__ = 'Whise, robgig1088, tabbernuk'
+	__category__ = 'Date and time'
 	__desc__ = __doc__
 
 	# internals
@@ -85,7 +86,7 @@ class ClearCalendarScreenlet(screenlets.Screenlet):
 	update_interval = 10
 	first_weekday = ''
 	enable_buttons = True
-	compact_calendar = True
+	compact_calendar = False
 	reader = iCal.ICalReader()
 	event1 = ''
 
