@@ -114,8 +114,9 @@ class ClockScreenlet (Screenlet):
     
     # default meta-info for Screenlets
     __name__    = 'ClockScreenlet'
-    __version__    = '0.7.4++'
+    __version__    = '0.7.4+++'
     __author__    = 'RYX (aka Rico Pfaus)'
+    __category__ = 'Date and time'
     __desc__    = __doc__
     
     # internal vars
