@@ -399,7 +399,6 @@ class SlideshowScreenlet (screenlets.Screenlet):
 	__name__		= 'SlideshowScreenlet'
 	__version__		= '1.3.10+++'
 	__author__		= 'Guido Tabbernuk <boamaod@gmail.com>'
-	__requires__		= ['python-imaging']
 	__desc__		= __doc__
 	
 	# attributes
@@ -901,7 +900,7 @@ class SlideshowScreenlet (screenlets.Screenlet):
 			elif self.engine1 == _('Media RSS'):
 				os.system('firefox ' + self.url + " &")
 			elif self.engine1 == _('Folder'):
-				os.system('gnome-open ' + chr(34) + self.__image + chr(34) + " &")
+				os.system('xdg-open ' + chr(34) + self.__image + chr(34) + " &")
 
 		if id == "wall":
 			# TODO: use DBus-call for this
